"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.convertFlowObjectTypeAnnotation = convertFlowObjectTypeAnnotation;

var _types = require("./types");

function flowTypeAnnotationToString(type) {
  switch (type.type) {
    case "NullableTypeAnnotation":
      return "?" + flowTypeAnnotationToString(type.typeAnnotation);
    case "BooleanTypeAnnotation":
      return "boolean";
    case "NumberTypeAnnotation":
      return "number";
    case "StringTypeAnnotation":
      return "string";
    default:
      return "any";
  }
}

// convert an ObjectTypeAnnotation to a js object
function convertFlowObjectTypeAnnotation(objectType) {
  return objectType.properties.reduce(function (obj, property) {
    var key = property.key.name;
    var value = property.value;
    if (value.type === "ObjectTypeAnnotation") {
      obj[key] = {
        type: "object",
        nullable: property.optional,
        properties: convertFlowObjectTypeAnnotation(value)
      };
    } else {
      obj[key] = {
        type: flowTypeAnnotationToString(value),
        nullable: property.optional
      };
    }
    return obj;
  }, {});
}